FirstDayOfWeek enum

Inheritance
Available extensions

Values

monday → const FirstDayOfWeek
const FirstDayOfWeek(2, 1)
sunday → const FirstDayOfWeek
const FirstDayOfWeek(1, 0)
saturday → const FirstDayOfWeek
const FirstDayOfWeek(0, -1)

Properties

addToCurrentDay int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isMonday bool
no setter
isSaturday bool
no setter
isSunday bool
no setter
minesFromMonthLength int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FirstDayOfWeek>
A constant List of the values in this enum, in order of their declaration.