I18nPersianMonths class
Constructors
- I18nPersianMonths({String farvardin = 'فروردین', String ordibehesht = 'اردیبهشت', String khordad = 'خرداد', String tir = 'تیر', String mordad = 'مرداد', String shahrivar = 'شهریور', String mehr = 'مهر', String aban = 'آبان', String azar = 'آذر', String dey = 'دی', String bahman = 'بهمن', String esfand = 'اسفند'})
-
const
Properties
- aban → String
-
final
- azar → String
-
final
- bahman → String
-
final
- dey → String
-
final
- esfand → String
-
final
- farvardin → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- khordad → String
-
final
- mehr → String
-
final
- mordad → String
-
final
- ordibehesht → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shahrivar → String
-
final
- tir → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited