I18nWeekCodes class

Constructors

I18nWeekCodes({String saturday = 'ش', String sunday = 'ی', String monday = 'د', String tuesday = 'س', String wednesday = 'چ', String thursday = 'پ', String friday = 'ج'})
const

Properties

friday String
final
hashCode int
The hash code for this object.
no setterinherited
monday String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturday String
final
sunday String
final
thursday String
final
tuesday String
final
wednesday String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited