InitCalendarHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
initCustomWeekCodes(
FirstDayOfWeek firstDayOfWeek, I18n i18n) → Map< int, String> -
initDefaultWeekCodes(
I18n i18n) → Map< int, String> -
initGregorianMonths(
I18n i18n) → Map< int, String> -
initJalaliMonths(
I18n i18n) → Map< int, String> -
initWeekNames(
I18n i18n) → Map< int, String>