I18nGregorianMonths class
Constructors
- I18nGregorianMonths({String january = 'ژانویه', String february = 'فوریه', String march = 'مارس', String april = 'آوریل', String may = 'مه', String june = 'ژوئن', String july = 'ژوئیه', String august = 'اوت', String september = 'سپتامبر', String october = 'اکتبر', String november = 'نوامبر', String december = 'دسامبر'})
-
const
Properties
- april → String
-
final
- august → String
-
final
- december → String
-
final
- february → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- january → String
-
final
- july → String
-
final
- june → String
-
final
- march → String
-
final
- may → String
-
final
- november → String
-
final
- october → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- september → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited