TodayContext class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TodayContext
Constructors
- TodayContext({required bool useGoToTodayButton, required bool showTodayBanner, required ButtonStyle? buttonStyle, required Color? onPrimaryColor, required Color? primaryColor, required double borderRadius, required String? title, required TextStyle? goTextStyle, required TextStyle? todayDateBannerTextStyle, required I18n i18n, required bool enablePersianDigits, Key? key})
-
const
Properties
- borderRadius → double
-
final
-
final
- enablePersianDigits → bool
-
final
- goTextStyle → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- i18n → I18n
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPrimaryColor → Color?
-
final
- primaryColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTodayBanner → bool
-
final
- title → String?
-
final
- todayDateBannerTextStyle → TextStyle?
-
final
- useGoToTodayButton → bool
-
final
Methods
-
bottomLeftBorderRadius(
BuildContext context) → Radius -
bottomRightBorderRadius(
BuildContext context) → Radius -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
formattedDate(
DatePickerState state) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited